@@ -193,8 +193,7 @@ def mcreate(paths):
         if os.path.exists(path) == False:
             os.mkdir(path)
  
-def onetickerx(ticker,fromx="2019-01-01",to="2122-01-01",api_token="",usecache=False):
-
+def onetickerx(ticker,fromx="2019-01-01",to="2122-01-01",api_token="",usecache=False):    
     filepath=f"data/ticker/{fromx}_{to}/{ticker}.json"
 
     if os.path.exists(filepath) and usecache: 
@@ -211,7 +210,8 @@ def onetickerx(ticker,fromx="2019-01-01",to="2122-01-01",api_token="",usecache=F
 
         if response.status_code != 200 or response.status_code >= 400:
             print(f"Could not retrieve {ticker}")
-            return None
+            shared._ERRORS[ticker]="Empty"
+            return utils.empty_df()
         else:
             mcreate([f"data",f"data/ticker",f"data/ticker/{fromx}_{to}"])
             with open(filepath,"w") as jsonfile:
@@ -221,8 +221,20 @@ def onetickerx(ticker,fromx="2019-01-01",to="2122-01-01",api_token="",usecache=F
             dx=_pd.read_json(jx)
             if len(dx.index.values) == 0:
                 print(f"{ticker} has no data {url}")
-                return None
+                shared._ERRORS[ticker]="Empty"
+                return utils.empty_df()
+
+            if "date" not in list(dx.columns):
+                print(f"{ticker} has no data {url}")
+                shared._ERRORS[ticker]="Empty"
+                return utils.empty_df()
+
+
             dx=dx.rename(columns={"date":"Date","open":"Open","high":"High","low":"Low","close":"Close","adjusted_close":"Adjusted_Close","volume":"Volume"})
+
+
+
+
             dx.set_index("Date",inplace=True)
 
             return dx.fillna(method='ffill').interpolate(method='linear')
